@@ -1,23 +1,27 @@
 mod state;
 
 use colored::*;
-use state::{FsEntry, State};
-use std::{cmp::min, fs::read_dir, path::Path};
+use state::{refresh_directory, FsEntry, State};
+use std::{cmp::min, time::Instant};
 use zellij_tile::prelude::*;
 
-const ROOT: &str = "/host";
-
 register_plugin!(State);
 
 impl ZellijPlugin for State {
     fn load(&mut self) {
         refresh_directory(self);
-        subscribe(&[EventType::KeyPress]);
+        subscribe(&[EventType::Key, EventType::Mouse]);
     }
 
     fn update(&mut self, event: Event) {
-        if let Event::KeyPress(key) = event {
-            match key {
+        let prev_event = if self.ev_history.len() == 2 {
+            self.ev_history.pop_front()
+        } else {
+            None
+        };
+        self.ev_history.push_back((event.clone(), Instant::now()));
+        match event {
+            Event::Key(key) => match key {
                 Key::Up | Key::Char('k') => {
                     *self.selected_mut() = self.selected().saturating_sub(1);
                 }
@@ -26,13 +30,8 @@ impl ZellijPlugin for State {
                     *self.selected_mut() = min(self.files.len() - 1, next);
                 }
                 Key::Right | Key::Char('\n') | Key::Char('l') if !self.files.is_empty() => {
-                    match self.files[self.selected()].clone() {
-                        FsEntry::Dir(p, _) => {
-                            self.path = p;
-                            refresh_directory(self);
-                        }
-                        FsEntry::File(p, _) => open_file(p.strip_prefix(ROOT).unwrap()),
-                    }
+                    self.traverse_dir_or_open_file();
+                    self.ev_history.clear();
                 }
                 Key::Left | Key::Char('h') => {
                     if self.path.components().count() > 2 {
@@ -44,14 +43,46 @@ impl ZellijPlugin for State {
                         refresh_directory(self);
                     }
                 }
-
                 Key::Char('.') => {
                     self.toggle_hidden_files();
                     refresh_directory(self);
                 }
 
                 _ => (),
-            };
+            },
+            Event::Mouse(mouse_event) => match mouse_event {
+                Mouse::ScrollDown(_) => {
+                    let next = self.selected().saturating_add(1);
+                    *self.selected_mut() = min(self.files.len().saturating_sub(1), next);
+                }
+                Mouse::ScrollUp(_) => {
+                    *self.selected_mut() = self.selected().saturating_sub(1);
+                }
+                Mouse::Release(Some((line, _))) => {
+                    if line < 0 {
+                        return;
+                    }
+                    let mut should_select = true;
+                    if let Some((Event::Mouse(Mouse::Release(Some((prev_line, _)))), t)) =
+                        prev_event
+                    {
+                        if prev_line == line
+                            && Instant::now().saturating_duration_since(t).as_millis() < 400
+                        {
+                            self.traverse_dir_or_open_file();
+                            self.ev_history.clear();
+                            should_select = false;
+                        }
+                    }
+                    if should_select && self.scroll() + (line as usize) < self.files.len() {
+                        *self.selected_mut() = self.scroll() + (line as usize);
+                    }
+                }
+                _ => {}
+            },
+            _ => {
+                dbg!("Unknown event {:?}", event);
+            }
         }
     }
 
@@ -63,6 +94,7 @@ impl ZellijPlugin for State {
             if self.selected() - self.scroll() + 2 > rows {
                 *self.scroll_mut() = self.selected() + 2 - rows;
             }
+
             let i = self.scroll() + i;
             if let Some(entry) = self.files.get(i) {
                 let mut path = entry.as_line(cols).normal();
@@ -82,24 +114,3 @@ impl ZellijPlugin for State {
         }
     }
 }
-
-fn refresh_directory(state: &mut State) {
-    state.files = read_dir(Path::new(ROOT).join(&state.path))
-        .unwrap()
-        .filter_map(|res| {
-            res.and_then(|d| {
-                if d.metadata()?.is_dir() {
-                    let children = read_dir(d.path())?.count();
-                    Ok(FsEntry::Dir(d.path(), children))
-                } else {
-                    let size = d.metadata()?.len();
-                    Ok(FsEntry::File(d.path(), size))
-                }
-            })
-            .ok()
-            .filter(|d| !d.is_hidden_file() || !state.hide_hidden_files)
-        })
-        .collect();
-
-    state.files.sort_unstable();
-}
