@@ -16,6 +16,7 @@ use zellij_utils::input::options::Options;
 use zellij_utils::nix;
 use zellij_utils::{
     cli::{CliArgs, Command, SessionCommand, Sessions},
+    envs,
     setup::{get_default_data_dir, Setup},
 };
 
@@ -39,7 +40,7 @@ pub(crate) fn kill_all_sessions(yes: bool) {
                     process::exit(1);
                 }
             }
-            for session in sessions.iter() {
+            for session in &sessions {
                 kill_session_impl(session);
             }
             process::exit(0);
@@ -130,7 +131,7 @@ fn attach_with_session_name(
     config_options: Options,
     create: bool,
 ) -> ClientInfo {
-    match session_name.as_ref() {
+    match &session_name {
         Some(session) if create => {
             if !session_exists(session).unwrap() {
                 ClientInfo::New(session_name.unwrap())
@@ -186,6 +187,13 @@ pub(crate) fn start_client(opts: CliArgs) {
             attach_with_session_name(session_name, config_options.clone(), create)
         };
 
+        if let Ok(val) = std::env::var(envs::SESSION_NAME_ENV_KEY) {
+            if val == *client.get_session_name() {
+                eprintln!("You are trying to attach to the current session(\"{}\"). Zellij does not support nesting a session in itself", val);
+                process::exit(1);
+            }
+        }
+
         let attach_layout = match client {
             ClientInfo::Attach(_, _) => None,
             ClientInfo::New(_) => layout,
