@@ -68,6 +68,7 @@ pub enum ScreenInstruction {
     TogglePaneFrames,
     SetSelectable(PaneId, bool, usize),
     ClosePane(PaneId, Option<ClientId>),
+    UpdatePaneName(Vec<u8>, ClientId),
     NewTab(Layout, Vec<RawFd>, ClientId),
     SwitchTabNext(ClientId),
     SwitchTabPrev(ClientId),
@@ -140,6 +141,7 @@ impl From<&ScreenInstruction> for ScreenContext {
             ScreenInstruction::TogglePaneFrames => ScreenContext::TogglePaneFrames,
             ScreenInstruction::SetSelectable(..) => ScreenContext::SetSelectable,
             ScreenInstruction::ClosePane(..) => ScreenContext::ClosePane,
+            ScreenInstruction::UpdatePaneName(..) => ScreenContext::UpdatePaneName,
             ScreenInstruction::NewTab(..) => ScreenContext::NewTab,
             ScreenInstruction::SwitchTabNext(..) => ScreenContext::SwitchTabNext,
             ScreenInstruction::SwitchTabPrev(..) => ScreenContext::SwitchTabPrev,
@@ -183,7 +185,8 @@ pub(crate) struct Screen {
     /// The indices of this [`Screen`]'s active [`Tab`]s.
     active_tab_indices: BTreeMap<ClientId, usize>,
     tab_history: BTreeMap<ClientId, Vec<usize>>,
-    mode_info: ModeInfo,
+    mode_info: BTreeMap<ClientId, ModeInfo>,
+    default_mode_info: ModeInfo, // TODO: restructure ModeInfo to prevent this duplication
     colors: Palette,
     draw_pane_frames: bool,
 }
@@ -206,7 +209,8 @@ impl Screen {
             tabs: BTreeMap::new(),
             overlay: OverlayWindow::default(),
             tab_history: BTreeMap::new(),
-            mode_info,
+            mode_info: BTreeMap::new(),
+            default_mode_info: mode_info,
             draw_pane_frames,
         }
     }
@@ -241,12 +245,15 @@ impl Screen {
         }
     }
     fn move_clients(&mut self, source_index: usize, destination_index: usize) {
-        let connected_clients_in_source_tab = {
+        let (connected_clients_in_source_tab, client_mode_infos_in_source_tab) = {
             let source_tab = self.tabs.get_mut(&source_index).unwrap();
             source_tab.drain_connected_clients()
         };
         let destination_tab = self.tabs.get_mut(&destination_index).unwrap();
-        destination_tab.add_multiple_clients(&connected_clients_in_source_tab);
+        destination_tab.add_multiple_clients(
+            connected_clients_in_source_tab,
+            client_mode_infos_in_source_tab,
+        );
     }
     /// A helper function to switch to a new tab at specified position.
     fn switch_active_tab(&mut self, new_tab_pos: usize, client_id: ClientId) {
@@ -268,7 +275,7 @@ impl Screen {
             // currently all clients are just mirrors, so we perform the action for every entry in
             // tab_history
             // TODO: receive a client_id and only do it for the client
-            for (client_id, tab_history) in self.tab_history.iter_mut() {
+            for (client_id, tab_history) in &mut self.tab_history {
                 let old_active_index = self.active_tab_indices.remove(client_id).unwrap();
                 self.active_tab_indices.insert(*client_id, new_tab_index);
                 tab_history.retain(|&e| e != new_tab_pos);
@@ -348,7 +355,7 @@ impl Screen {
 
     pub fn resize_to_screen(&mut self, new_screen_size: Size) {
         self.size = new_screen_size;
-        for (_, tab) in self.tabs.iter_mut() {
+        for tab in self.tabs.values_mut() {
             tab.resize_whole_tab(new_screen_size);
             tab.set_force_render();
         }
@@ -361,7 +368,7 @@ impl Screen {
         let mut tabs_to_close = vec![];
         let size = self.size;
         let overlay = self.overlay.clone();
-        for (tab_index, tab) in self.tabs.iter_mut() {
+        for (tab_index, tab) in &mut self.tabs {
             if tab.has_active_panes() {
                 let vte_overlay = overlay.generate_overlay(size);
                 tab.render(&mut output, Some(vte_overlay));
@@ -423,6 +430,11 @@ impl Screen {
     pub fn new_tab(&mut self, layout: Layout, new_pids: Vec<RawFd>, client_id: ClientId) {
         let tab_index = self.get_new_tab_index();
         let position = self.tabs.len();
+        let client_mode_info = self
+            .mode_info
+            .get(&client_id)
+            .unwrap_or(&self.default_mode_info)
+            .clone();
         let mut tab = Tab::new(
             tab_index,
             position,
@@ -431,23 +443,28 @@ impl Screen {
             self.bus.os_input.as_ref().unwrap().clone(),
             self.bus.senders.clone(),
             self.max_panes,
-            self.mode_info.clone(),
+            client_mode_info,
             self.colors,
             self.draw_pane_frames,
             client_id,
         );
-        tab.apply_layout(layout, new_pids, tab_index);
+        tab.apply_layout(layout, new_pids, tab_index, client_id);
         if let Some(active_tab) = self.get_active_tab_mut(client_id) {
             active_tab.visible(false);
-            let connected_clients = active_tab.drain_connected_clients();
-            tab.add_multiple_clients(&connected_clients);
+            let (connected_clients_in_source_tab, client_mode_infos_in_source_tab) =
+                active_tab.drain_connected_clients();
+            tab.add_multiple_clients(
+                connected_clients_in_source_tab,
+                client_mode_infos_in_source_tab,
+            );
         }
-        for (client_id, tab_history) in self.tab_history.iter_mut() {
+        for (client_id, tab_history) in &mut self.tab_history {
             let old_active_index = self.active_tab_indices.remove(client_id).unwrap();
             self.active_tab_indices.insert(*client_id, tab_index);
             tab_history.retain(|&e| e != tab_index);
             tab_history.push(old_active_index);
         }
+        tab.update_input_modes();
         tab.visible(true);
         self.tabs.insert(tab_index, tab);
         if !self.active_tab_indices.contains_key(&client_id) {
@@ -503,7 +520,11 @@ impl Screen {
             }
             self.bus
                 .senders
-                .send_to_plugin(PluginInstruction::Update(None, Event::TabUpdate(tab_data)))
+                .send_to_plugin(PluginInstruction::Update(
+                    None,
+                    None,
+                    Event::TabUpdate(tab_data),
+                ))
                 .unwrap();
         }
     }
@@ -526,7 +547,12 @@ impl Screen {
         self.update_tabs();
     }
     pub fn change_mode(&mut self, mode_info: ModeInfo, client_id: ClientId) {
-        if self.mode_info.mode == InputMode::Scroll
+        let previous_mode = self
+            .mode_info
+            .get(&client_id)
+            .unwrap_or(&self.default_mode_info)
+            .mode;
+        if previous_mode == InputMode::Scroll
             && (mode_info.mode == InputMode::Normal || mode_info.mode == InputMode::Locked)
         {
             self.get_active_tab_mut(client_id)
@@ -534,9 +560,9 @@ impl Screen {
                 .clear_active_terminal_scroll(client_id);
         }
         self.colors = mode_info.palette;
-        self.mode_info = mode_info;
+        self.mode_info.insert(client_id, mode_info.clone());
         for tab in self.tabs.values_mut() {
-            tab.mode_info = self.mode_info.clone();
+            tab.change_mode_info(mode_info.clone(), client_id);
             tab.mark_active_pane_for_rerender(client_id);
         }
     }
@@ -941,8 +967,8 @@ pub(crate) fn screen_thread_main(
                         screen.get_active_tab_mut(client_id).unwrap().close_pane(id);
                     }
                     None => {
-                        for (_index, tab) in screen.tabs.iter_mut() {
-                            if tab.get_pane_ids().iter().any(|pid| *pid == id) {
+                        for tab in screen.tabs.values_mut() {
+                            if tab.get_pane_ids().contains(&id) {
                                 tab.close_pane(id);
                                 break;
                             }
@@ -951,6 +977,14 @@ pub(crate) fn screen_thread_main(
                 }
                 screen.update_tabs();
             }
+            ScreenInstruction::UpdatePaneName(c, client_id) => {
+                screen
+                    .get_active_tab_mut(client_id)
+                    .unwrap()
+                    .update_active_pane_name(c, client_id);
+
+                screen.render();
+            }
             ScreenInstruction::ToggleActiveTerminalFullscreen(client_id) => {
                 screen
                     .get_active_tab_mut(client_id)
@@ -962,7 +996,7 @@ pub(crate) fn screen_thread_main(
             }
             ScreenInstruction::TogglePaneFrames => {
                 screen.draw_pane_frames = !screen.draw_pane_frames;
-                for (_, tab) in screen.tabs.iter_mut() {
+                for tab in screen.tabs.values_mut() {
                     tab.set_pane_frames(screen.draw_pane_frames);
                 }
                 screen.render();
@@ -1100,6 +1134,7 @@ pub(crate) fn screen_thread_main(
             }
             ScreenInstruction::AddClient(client_id) => {
                 screen.add_client(client_id);
+                screen.update_tabs();
 
                 screen.render();
             }
