@@ -13,7 +13,6 @@ pub struct PaneContentsAndUi<'a> {
     colors: Palette,
     focused_clients: Vec<ClientId>,
     multiple_users_exist_in_session: bool,
-    mode: InputMode, // TODO: per client
 }
 
 impl<'a> PaneContentsAndUi<'a> {
@@ -22,7 +21,6 @@ impl<'a> PaneContentsAndUi<'a> {
         output: &'a mut Output,
         colors: Palette,
         active_panes: &HashMap<ClientId, PaneId>,
-        mode: InputMode,
     ) -> Self {
         let focused_clients: Vec<ClientId> = active_panes
             .iter()
@@ -36,11 +34,10 @@ impl<'a> PaneContentsAndUi<'a> {
             colors,
             focused_clients,
             multiple_users_exist_in_session,
-            mode,
         }
     }
     pub fn render_pane_contents_for_all_clients(&mut self) {
-        if let Some(vte_output) = self.pane.render() {
+        if let Some(vte_output) = self.pane.render(None) {
             // FIXME: Use Termion for cursor and style clearing?
             self.output.push_str_to_all_clients(&format!(
                 "\u{1b}[{};{}H\u{1b}[m{}",
@@ -50,19 +47,33 @@ impl<'a> PaneContentsAndUi<'a> {
             ));
         }
     }
+    pub fn render_pane_contents_for_client(&mut self, client_id: ClientId) {
+        if let Some(vte_output) = self.pane.render(Some(client_id)) {
+            // FIXME: Use Termion for cursor and style clearing?
+            self.output.push_to_client(
+                client_id,
+                &format!(
+                    "\u{1b}[{};{}H\u{1b}[m{}",
+                    self.pane.y() + 1,
+                    self.pane.x() + 1,
+                    vte_output
+                ),
+            );
+        }
+    }
     pub fn render_fake_cursor_if_needed(&mut self, client_id: ClientId) {
         let pane_focused_for_client_id = self.focused_clients.contains(&client_id);
         let pane_focused_for_different_client = self
             .focused_clients
             .iter()
-            .filter(|c_id| **c_id != client_id)
+            .filter(|&&c_id| c_id != client_id)
             .count()
             > 0;
         if pane_focused_for_different_client && !pane_focused_for_client_id {
             let fake_cursor_client_id = self
                 .focused_clients
                 .iter()
-                .find(|c_id| **c_id != client_id)
+                .find(|&&c_id| c_id != client_id)
                 .unwrap();
             if let Some(colors) = client_id_to_colors(*fake_cursor_client_id, self.colors) {
                 if let Some(vte_output) = self.pane.render_fake_cursor(colors.0, colors.1) {
@@ -79,17 +90,22 @@ impl<'a> PaneContentsAndUi<'a> {
             }
         }
     }
-    pub fn render_pane_frame(&mut self, client_id: ClientId, session_is_mirrored: bool) {
+    pub fn render_pane_frame(
+        &mut self,
+        client_id: ClientId,
+        client_mode: InputMode,
+        session_is_mirrored: bool,
+    ) {
         let pane_focused_for_client_id = self.focused_clients.contains(&client_id);
         let other_focused_clients: Vec<ClientId> = self
             .focused_clients
             .iter()
-            .filter(|c_id| **c_id != client_id)
+            .filter(|&&c_id| c_id != client_id)
             .copied()
             .collect();
         let pane_focused_for_differet_client = !other_focused_clients.is_empty();
 
-        let frame_color = self.frame_color(client_id, self.mode, session_is_mirrored);
+        let frame_color = self.frame_color(client_id, client_mode, session_is_mirrored);
         let focused_client = if pane_focused_for_client_id {
             Some(client_id)
         } else if pane_focused_for_differet_client {
@@ -116,7 +132,7 @@ impl<'a> PaneContentsAndUi<'a> {
                 other_cursors_exist_in_session: self.multiple_users_exist_in_session,
             }
         };
-        if let Some(vte_output) = self.pane.render_frame(client_id, frame_params) {
+        if let Some(vte_output) = self.pane.render_frame(client_id, frame_params, client_mode) {
             // FIXME: Use Termion for cursor and style clearing?
             self.output.push_to_client(
                 client_id,
@@ -132,10 +148,11 @@ impl<'a> PaneContentsAndUi<'a> {
     pub fn render_pane_boundaries(
         &self,
         client_id: ClientId,
+        client_mode: InputMode,
         boundaries: &mut Boundaries,
         session_is_mirrored: bool,
     ) {
-        let color = self.frame_color(client_id, self.mode, session_is_mirrored);
+        let color = self.frame_color(client_id, client_mode, session_is_mirrored);
         boundaries.add_rect(self.pane.as_ref(), color);
     }
     fn frame_color(
