@@ -22,7 +22,7 @@ pub fn get_mode_info(
     capabilities: PluginCapabilities,
 ) -> ModeInfo {
     let keybinds = match mode {
-        InputMode::Normal | InputMode::Locked => Vec::new(),
+        InputMode::Normal | InputMode::Locked | InputMode::Prompt => Vec::new(),
         InputMode::Resize => vec![
             ("←↓↑→".to_string(), "Resize".to_string()),
             ("+-".to_string(), "Increase/Decrease size".to_string()),
@@ -40,6 +40,7 @@ pub fn get_mode_info(
             ("x".to_string(), "Close".to_string()),
             ("f".to_string(), "Fullscreen".to_string()),
             ("z".to_string(), "Frames".to_string()),
+            ("c".to_string(), "Rename".to_string()),
         ],
         InputMode::Tab => vec![
             ("←↓↑→".to_string(), "Move focus".to_string()),
@@ -55,6 +56,7 @@ pub fn get_mode_info(
             ("u/d".to_string(), "Scroll Half Page".to_string()),
         ],
         InputMode::RenameTab => vec![("Enter".to_string(), "when done".to_string())],
+        InputMode::RenamePane => vec![("Enter".to_string(), "when done".to_string())],
         InputMode::Session => vec![("d".to_string(), "Detach".to_string())],
     };
 
